@@ -11,8 +11,6 @@ from sklearn.decomposition import PCA
 _required_opts = ['analytic', 'ntries']
 _logger = logging.getLogger(__name__)
 
-np.random.seed(1)
-
 
 @dataclass
 class PilotOutput:
@@ -62,9 +60,8 @@ def pilot(X, Y, featlabels=None, **kwargs):
     else:
         _logger.info("PILOT is solving numerically the projection problem.")
         ntries = kwargs['ntries']
-        # seed = kwargs['seed'] if 'seed' in kwargs else 1
-        if 'seed' in kwargs:
-            np.random.seed(kwargs['seed'])
+        seed = kwargs['seed'] if 'seed' in kwargs else 1
+        np.random.seed(seed)
         X0 = 2 * np.random.random((ntries, 2 * m + 2 * n)).T - 1
         alpha = np.zeros((2 * m + 2 * n, ntries))
         eoptim = np.zeros(ntries)
@@ -96,10 +93,10 @@ def pilot(X, Y, featlabels=None, **kwargs):
     return out
 
 
-def adjust_rotation(Z, feat=None, theta=-135):
+def adjust_rotation(Z, w=None, theta=-135):
     pca = PCA(n_components=1)
-    if feat is not None:
-        pca.fit(np.hstack((Z, feat)))
+    if w is not None:
+        pca.fit(np.hstack((Z, w)))
     else:
         pca.fit(Z)
     theta = np.radians(theta) + np.arctan2(pca.components_[0][1], pca.components_[0][0])
