@@ -5,12 +5,12 @@ from itertools import compress
 
 import numpy as np
 import pandas as pd
+from scipy.stats import mode
 
 from . import preprocessing
 from .pilot import PilotOutput, pilot, adjust_rotation
 from .trace import TraceOutput, trace
 
-
 _feature_prefix = 'feature_'
 _algo_prefix = 'algo_'
 
@@ -48,8 +48,8 @@ def train_is(metadata: pd.DataFrame, opts: dict) -> Model:
     :rtype: Model
     """
     logger = logging.getLogger(__name__)
-    logger.info(f"Listing options to be used:")
-    logger.info(json.dumps(opts, indent=4))
+    # logger.info(f"Listing options to be used:")
+    # logger.info(json.dumps(opts, indent=4))
 
     data = Data()
     data.instlabels = metadata.index.copy()
@@ -76,7 +76,7 @@ def train_is(metadata: pd.DataFrame, opts: dict) -> Model:
             msg = msg + f"higher than {opts['perf']['epsilon']}"
         else:
             data.Ybin = np.greater_equal(Yaux, (1 - epsilon) * data.bestPerformace)
-            msg = msg + f"within {np.round(100*opts['perf']['epsilon'])}% of the best."
+            msg = msg + f"within {np.round(100 * opts['perf']['epsilon'])}% of the best."
     else:
         Yaux = Yraw.fillna(np.inf).values
         rankPerf = np.sort(Yaux, axis=1)[:, ::-1]
@@ -88,7 +88,7 @@ def train_is(metadata: pd.DataFrame, opts: dict) -> Model:
             msg = msg + f"less than {opts['perf']['epsilon']}"
         else:
             data.Ybin = np.less_equal(Yaux, (1 + epsilon) * data.bestPerformace)
-            msg = msg + f"within {np.round(100*opts['perf']['epsilon'])}% of the best."
+            msg = msg + f"within {np.round(100 * opts['perf']['epsilon'])}% of the best."
     logger.info(msg)
 
     nalgos = data.Y.shape[1]
@@ -132,7 +132,8 @@ def train_is(metadata: pd.DataFrame, opts: dict) -> Model:
     logger.info("Calling PILOT to find the optimal projection.")
     model.pilot = pilot(data.X, data.Y, featlabels=data.featlabels, **opts['pilot'])
 
-    # model.pilot.Z = adjust_rotation(model.pilot.Z)
+    # model.pilot.Z = adjust_rotation(model.pilot.Z, ~model.data.Ybin.any(axis=1).reshape(-1, 1))
+    # model.pilot.Z = adjust_rotation(model.pilot.Z, ~mode(model.data.Ybin, axis=1)[0])
 
     logger.info("Calling TRACE to perform the footprint analysis.")
     model.trace = trace(model.pilot.Z, model.data.Ybin, model.data.P,
